==> ec2-0.16.0-sources.jar: software/amazon/awscdk/services/ec2/VpcSubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a new VPC subnet resource
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-12T19:56:02.680Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.VpcSubnet")
public class VpcSubnet extends software.amazon.awscdk.services.ec2.VpcSubnetRef implements software.amazon.awscdk.ITaggable {
    protected VpcSubnet(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public VpcSubnet(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.VpcSubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    protected void addDefaultRouteToIGW(final java.lang.String gatewayId) {
        this.jsiiCall("addDefaultRouteToIGW", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(gatewayId, "gatewayId is required")).toArray());
    }

    protected void addDefaultRouteToNAT(final java.lang.String natGatewayId) {
        this.jsiiCall("addDefaultRouteToNAT", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(natGatewayId, "natGatewayId is required")).toArray());
    }

    /**
     * The Availability Zone the subnet is located in
     */
    @Override
    public java.lang.String getAvailabilityZone() {
        return this.jsiiGet("availabilityZone", java.lang.String.class);
    }

    /**
     * The subnetId for this particular subnet
     */
    @Override
    public java.lang.String getSubnetId() {
        return this.jsiiGet("subnetId", java.lang.String.class);
    }

    /**
     * Manage tags for Construct and propagate to children
     */
    @Override
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
}

==> ec2-0.17.0-sources.jar: software/amazon/awscdk/services/ec2/VpcSubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a new VPC subnet resource
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-14T09:49:44.788Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.VpcSubnet")
public class VpcSubnet extends software.amazon.awscdk.services.ec2.VpcSubnetRef implements software.amazon.awscdk.ITaggable {
    protected VpcSubnet(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public VpcSubnet(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.VpcSubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Create a default route that points to a passed IGW, with a dependency
     * on the IGW's attachment to the VPC.
     */
    protected void addDefaultRouteToIGW(final software.amazon.awscdk.services.ec2.cloudformation.InternetGatewayResource gateway, final software.amazon.awscdk.services.ec2.cloudformation.VPCGatewayAttachmentResource gatewayAttachment) {
        this.jsiiCall("addDefaultRouteToIGW", Void.class, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(gateway, "gateway is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(gatewayAttachment, "gatewayAttachment is required"))).toArray());
    }

    protected void addDefaultRouteToNAT(final java.lang.String natGatewayId) {
        this.jsiiCall("addDefaultRouteToNAT", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(natGatewayId, "natGatewayId is required")).toArray());
    }

    /**
     * The Availability Zone the subnet is located in
     */
    @Override
    public java.lang.String getAvailabilityZone() {
        return this.jsiiGet("availabilityZone", java.lang.String.class);
    }

    /**
     * The subnetId for this particular subnet
     */
    @Override
    public java.lang.String getSubnetId() {
        return this.jsiiGet("subnetId", java.lang.String.class);
    }

    /**
     * Manage tags for Construct and propagate to children
     */
    @Override
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
}
